@@ -18,11 +18,11 @@ def get_metadata():
         "author": "Peter Krueck (adapted for automagik-tools)",
         "tools": [
             "consult_gemini",
-            "list_sessions", 
+            "list_sessions",
             "end_session",
-            "get_gemini_requests"
-        ]
+            "get_gemini_requests",
+        ],
     }
 
 
-__all__ = ["create_server", "get_config_class", "get_metadata"]
\ No newline at end of file
+__all__ = ["create_server", "get_config_class", "get_metadata"]
